Summary:	A tool for creating scanners (text pattern recognizers)
Name:		flex
Version:	2.6.4
Release:	%mkrel 8
License:	BSD
Group:		Development/Other
URL: 		https://flex.sourceforge.net/
Source0:	https://github.com/westes/flex/releases/download/v%{version}/%{name}-%{version}.tar.gz
Patch1:		flex-2.6.4-libtool.patch
# Fixes segfault with glibc >= 2.26
Patch2:		flex-2.6.4-AC_USE_SYSTEM_EXTENSIONS.patch
BuildRequires:	bison
BuildRequires:	gettext-devel
BuildRequires:	help2man
BuildRequires:	indent
Requires:	m4
Conflicts:	flex-reentrant

%description
The flex program generates scanners. Scanners are
programs which can recognize lexical patterns in text.

Flex takes pairs of regular expressions and C code as input and
generates a C source file as output. The output file is compiled and
linked with a library to produce an executable.

The executable searches through its input for occurrences of the
regular expressions. When a match is found, it executes the
corresponding C code.

Flex was designed to work with both Yacc and Bison, and is used by
many programs as part of their build process.

You should install flex if you are going to use your system for
application development.

%prep
%setup -q
%patch -P 1 -p1 -b .LIBT
%patch -P 2 -p1 -b .AC_USE_SYSTEM_EXTENSIONS

# Force regeneration of skel.c with corrected pointers.
rm -f skel.c

%build
autoreconf -fi
export CFLAGS="-fPIC %{optflags}"
%configure \
	--disable-rpath
%make_build

%check
#(tpg) these tests used features removed in bison-2.6
sed -i -e '/test-bison-yylloc/d' -e '/test-bison-yylval/d' tests/Makefile.in

make check

%install
%make_install

%find_lang %{name}

pushd %{buildroot}
ln -sf flex .%{_bindir}/lex
ln -s flex.1 .%{_mandir}/man1/lex.1
ln -s flex.1 .%{_mandir}/man1/flex++.1
popd

%files -f %{name}.lang
%doc %{_docdir}/%{name}/AUTHORS
%doc %{_docdir}/%{name}/COPYING
%doc %{_docdir}/%{name}/NEWS
%doc %{_docdir}/%{name}/ONEWS
%doc %{_docdir}/%{name}/README.md
%{_bindir}/*
%{_mandir}/man1/*
%{_libdir}/libfl*.a
%{_includedir}/FlexLexer.h
%{_infodir}/*


%changelog
* Mon Jun 30 2025 umeabot <umeabot> 2.6.4-8.mga10
+ Revision: 2231786
- Mageia 10 Mass Rebuild

* Sat Dec 21 2024 pterjan <pterjan> 2.6.4-7.mga10
+ Revision: 2127310
- Rebuild for patchN deprecation

* Thu Mar 17 2022 umeabot <umeabot> 2.6.4-6.mga9
+ Revision: 1797013
- Mageia 9 Mass Rebuild

* Tue Jun 30 2020 joequant <joequant> 2.6.4-5.mga8
+ Revision: 1600662
- rebuild

* Thu Feb 13 2020 umeabot <umeabot> 2.6.4-4.mga8
+ Revision: 1512314
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x
- replace deprecated %%makeinstall_std

* Sun Sep 23 2018 umeabot <umeabot> 2.6.4-3.mga7
+ Revision: 1297722
- Mageia 7 Mass Rebuild

* Mon Jul 16 2018 pterjan <pterjan> 2.6.4-2.mga7
+ Revision: 1243890
- Add a patch fixing a segfault when built against new glibc

* Tue Oct 03 2017 shlomif <shlomif> 2.6.4-1.mga7
+ Revision: 1168050
- New version 2.6.4

* Sun Jan 08 2017 akien <akien> 2.6.1-3.mga6
+ Revision: 1080649
- Revert to 2.6.1 again, version 2.6.3 is *also* bogus

* Fri Dec 30 2016 luigiwalser <luigiwalser> 2.6.3-1.mga6
+ Revision: 1078727
- 2.6.3
- rediff patch 1
- fix README name

* Tue Nov 01 2016 akien <akien> 2.6.1-2.mga6
+ Revision: 1064505
- Revert to 2.6.1, previous version is buggy:
  https://github.com/westes/flex/issues/113

* Wed Oct 26 2016 luigiwalser <luigiwalser> 2.6.2-1.mga6
+ Revision: 1063663
- 2.6.2
- rediff patch1

* Fri Apr 08 2016 shlomif <shlomif> 2.6.1-1.mga6
+ Revision: 999503
- New version 2.6.1

* Thu Jan 21 2016 neoclust <neoclust> 2.6.0-2.mga6
+ Revision: 926221
- Add P2: Commented in C style in skeleton; fixed sf#195

* Thu Jan 07 2016 luigiwalser <luigiwalser> 2.6.0-1.mga6
+ Revision: 920352
- 2.6.0
- update patch 1

* Wed Oct 14 2015 blino <blino> 2.5.39-4.mga6
+ Revision: 891680
- package more docs to fix build with rpm 4.13

* Wed Oct 15 2014 umeabot <umeabot> 2.5.39-3.mga5
+ Revision: 745016
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.5.39-2.mga5
+ Revision: 679231
- Mageia 5 Mass Rebuild
+ shlomif <shlomif>
- Remove a patch for a file that is right away being deleted.
  Thanks to blino for noticing it.

* Thu Mar 27 2014 luigiwalser <luigiwalser> 2.5.39-1.mga5
+ Revision: 608968
- 2.5.39

* Sun Feb 16 2014 luigiwalser <luigiwalser> 2.5.38-1.mga5
+ Revision: 593007
- disable bison tests again, apparently not quite fixed upstream
- revert building libraries with libtool (does not link successfully)
- re-enable disabled tests that were broken with bison 2.6 (fixed upstream)
+ fwang <fwang>
- 2.5.38

* Fri Oct 18 2013 umeabot <umeabot> 2.5.37-3.mga4
+ Revision: 504496
- Mageia 4 Mass Rebuild

* Fri Jan 11 2013 umeabot <umeabot> 2.5.37-2.mga3
+ Revision: 350520
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Aug 26 2012 luigiwalser <luigiwalser> 2.5.37-1.mga3
+ Revision: 284053
- build fixes from mdv
+ fwang <fwang>
- br pdf generator
- br autopoint
- new version 2.5.37

* Sun Jun 10 2012 blino <blino> 2.5.35-8.mga3
+ Revision: 259448
- rebuild to get info pages as xz instead of lzma
+ supp <supp>
- imported package flex

* Sat Jan 08 2011 blino <blino> 2.5.35-7.mga1
+ Revision: 421
- imported package flex


* Thu Dec 02 2010 Oden Eriksson <oeriksson@mandriva.com> 2.5.35-7mdv2011.0
+ Revision: 605151
- rebuild

* Sun Mar 14 2010 Oden Eriksson <oeriksson@mandriva.com> 2.5.35-6mdv2010.1
+ Revision: 518999
- rebuild

* Wed Oct 21 2009 Frederik Himpe <fhimpe@mandriva.org> 2.5.35-5mdv2010.0
+ Revision: 458597
- Add Requires: m4 to make sure lex can work (bug #54782)

* Sun May 03 2009 Frederik Himpe <fhimpe@mandriva.org> 2.5.35-4mdv2010.0
+ Revision: 371154
- Build with -fPIC, needed to build ipsec-tools on x86_64
- Add Fedora patches fixing build warnings

* Sat Dec 20 2008 Oden Eriksson <oeriksson@mandriva.com> 2.5.35-3mdv2009.1
+ Revision: 316579
- rediffed one fuzzy patch

* Wed Aug 06 2008 Thierry Vignaud <tv@mandriva.org> 2.5.35-2mdv2009.0
+ Revision: 264465
- rebuild early 2009.0 package (before pixel changes)

* Thu Apr 17 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 2.5.35-1mdv2009.0
+ Revision: 195398
- new version
- license is BSD not a GPL
- nuke rpath
- spec file clean
- enable checks

* Sat Jan 12 2008 Thierry Vignaud <tv@mandriva.org> 2.5.33-3mdv2008.1
+ Revision: 149727
- rebuild
- kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot


* Sat Jan 13 2007 Götz Waschk <waschk@mandriva.org> 2.5.33-2mdv2007.0
+ Revision: 108195
- use find-lang

* Tue Oct 24 2006 Rafael Garcia-Suarez <rgarciasuarez@mandriva.com> 2.5.33-1mdv2007.1
+ Revision: 71736
- New version of flex.
  Remove obsolete patches, and add info pages and localized messages.

  + Oden Eriksson <oeriksson@mandriva.com>
    - bzip2 cleanup
    - bunzip patches
    - Import flex

* Mon Jul 03 2006 Oden Eriksson <oeriksson@mandriva.com> 2.5.4a-25mdv2007.0
- make it conflict with flex-reentrant

* Mon May 15 2006 Stefan van der Eijk <stefan@eijk.nu> 2.5.4a-24mdk
- rebuild for sparc

* Sat Dec 31 2005 Mandriva Linux Team <http://www.mandrivaexpert.com/> 2.5.4a-23mdk
- Rebuild

* Wed Jun 09 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 2.5.4a-22mdk
- fix buildrequires
- wipe out buildroot in %%install, not %%prep

